==> haskell-contravariant-1.5.2-4-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-contravariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant
version:              1.5.2
visibility:           public
id:                   contravariant-1.5.2-2jV68Ctq1IVAc8M3y7yJKu
key:                  contravariant-1.5.2-2jV68Ctq1IVAc8M3y7yJKu
license:              BSD-3-Clause
copyright:            Copyright (C) 2007-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/contravariant/
synopsis:             Contravariant functors
description:          Contravariant functors.
category:             Control, Data
abi:                  f333c833d2c2e532d746aaa84547ebd3
exposed:              True
exposed-modules:
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic

import-dirs:          /usr/lib/ghc-8.8.3/site-local/contravariant-1.5.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/contravariant-1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/contravariant-1.5.2
hs-libraries:         HScontravariant-1.5.2-2jV68Ctq1IVAc8M3y7yJKu
depends:
    StateVar-1.1.1.1-L09KIp33uUYEpD2XQSjrks base-4.13.0.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-contravariant/html/contravariant.haddock

haddock-html:         /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-contravariant-1.5.2-5-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-contravariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 contravariant
version:              1.5.2
visibility:           public
id:                   contravariant-1.5.2-DwdzLJHM56h4vdKMLDlSPX
key:                  contravariant-1.5.2-DwdzLJHM56h4vdKMLDlSPX
license:              BSD-3-Clause
copyright:            Copyright (C) 2007-2015 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/contravariant/
synopsis:             Contravariant functors
description:          Contravariant functors.
category:             Control, Data
abi:                  eb32acfc701496cf0fa7cac3eb7276f5
exposed:              True
exposed-modules:
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible
    Data.Functor.Contravariant.Generic

import-dirs:          /usr/lib/ghc-8.8.3/site-local/contravariant-1.5.2
library-dirs:         /usr/lib/ghc-8.8.3/site-local/contravariant-1.5.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/contravariant-1.5.2
hs-libraries:         HScontravariant-1.5.2-DwdzLJHM56h4vdKMLDlSPX
depends:
    StateVar-1.2-9GFTup1qqdWAy26rtsnB7R base-4.13.0.0
    transformers-0.5.6.2

haddock-interfaces:
    /usr/share/doc/haskell-contravariant/html/contravariant.haddock

haddock-html:         /usr/share/doc/haskell-contravariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
